pub unsafe extern "C" fn kadm5_init(
context: krb5_context,
client_name: *mut c_char,
pass: *mut c_char,
service_name: *mut c_char,
params: *mut kadm5_config_params,
struct_version: krb5_ui_4,
api_version: krb5_ui_4,
db_args: *mut *mut c_char,
server_handle: *mut *mut c_void,
) -> kadm5_ret_tExpand description
For all initialization functions, the caller must first initialize a context with kadm5_init_krb5_context which will survive as long as the resulting handle. The caller should free the context with krb5_free_context.