krb5_init_context

Function krb5_init_context 

pub unsafe extern "C" fn krb5_init_context(
    context: *mut krb5_context,
) -> krb5_error_code
Create a krb5 library context.

@param [out] context Library context

The @a context must be released by calling krb5_free_context() when it is no longer needed.

@warning Any program or module that needs the Kerberos code to not trust the environment must use krb5_init_secure_context(), or clean out the environment.

@retval 0 Success @return Kerberos error codes