_krb5_key_data

Struct _krb5_key_data 

#[repr(C)]
pub struct _krb5_key_data { pub key_data_ver: krb5_int16, pub key_data_kvno: krb5_ui_2, pub key_data_type: [krb5_int16; 2], pub key_data_length: [krb5_ui_2; 2], pub key_data_contents: [*mut krb5_octet; 2], }
If this ever changes up the version number and make the arrays be as big as necessary.

Currently the first type is the enctype and the second is the salt type.

Fields

key_data_ver: krb5_int16

Version

key_data_kvno: krb5_ui_2

Key Version

key_data_type: [krb5_int16; 2]

Array of types

key_data_length: [krb5_ui_2; 2]

Array of lengths

key_data_contents: [*mut krb5_octet; 2]

Array of pointers