#[repr(C)]pub struct _krb5_tl_data {
pub tl_data_next: *mut _krb5_tl_data,
pub tl_data_type: krb5_int16,
pub tl_data_length: krb5_ui_2,
pub tl_data_contents: *mut krb5_octet,
}Expand description
Note — these structures cannot be modified without changing the database version number in libkdb.a, but should be expandable by adding new tl_data types.
Fields
tl_data_next: *mut _krb5_tl_dataNOT saved
tl_data_type: krb5_int16tl_data_length: krb5_ui_2tl_data_contents: *mut krb5_octetTrait Implementations
Sourceimpl Clone for _krb5_tl_data
impl Clone for _krb5_tl_data
Sourcefn clone(&self) -> _krb5_tl_data
fn clone(&self) -> _krb5_tl_data
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for _krb5_tl_data
impl Debug for _krb5_tl_data
Sourceimpl Default for _krb5_tl_data
impl Default for _krb5_tl_data
impl Copy for _krb5_tl_data