krb5_key_data

Type Alias krb5_key_data 

pub type krb5_key_data = _krb5_key_data;
If this ever changes up the version number and make the arrays be as big as necessary.

Currently the first type is the enctype and the second is the salt type.

Aliased Type

#[repr(C)]
pub struct krb5_key_data { pub key_data_ver: i16, pub key_data_kvno: u16, pub key_data_type: [i16; 2], pub key_data_length: [u16; 2], pub key_data_contents: [*mut u8; 2], }

Fields

key_data_ver: i16

Version

key_data_kvno: u16

Key Version

key_data_type: [i16; 2]

Array of types

key_data_length: [u16; 2]

Array of lengths

key_data_contents: [*mut u8; 2]

Array of pointers