pub unsafe extern "C" fn krb5_cc_default(
context: krb5_context,
ccache: *mut krb5_ccache,
) -> krb5_error_codeExpand description
Resolve the default credential cache name.
@param [in] context Library context @param [out] ccache Pointer to credential cache name
Create a handle to the default credential cache as given by krb5_cc_default_name().
@retval 0 Success @retval KV5M_CONTEXT Bad magic number for @c _krb5_context structure @retval KRB5_FCC_INTERNAL The name of the default credential cache cannot be obtained @return Kerberos error codes