pub unsafe extern "C" fn krb5_cc_resolve(
context: krb5_context,
name: *const c_char,
cache: *mut krb5_ccache,
) -> krb5_error_codeExpand description
Resolve a credential cache name.
@param [in] context Library context @param [in] name Credential cache name to be resolved @param [out] cache Credential cache handle
Fills in @a cache with a @a cache handle that corresponds to the name in @a name. @a name should be of the form @c type:residual, and @a type must be a type known to the library. If the @a name does not contain a colon, interpret it as a file name.
@code Example: krb5_cc_resolve(context, “MEMORY:C_”, &cache); @endcode
@retval 0 Success @return Kerberos error codes